@@ -256,6 +256,14 @@ void BinaryWriterSpec::WriteConst(const Const& const_) {
       break;
     }
 
+    case Type::ExnRef: {
+      WriteString("exnref");
+      WriteSeparator();
+      WriteKey("value");
+      WriteRefBits(const_.ref_bits());
+      break;
+    }
+
     case Type::V128: {
       WriteString("v128");
       WriteSeparator();
@@ -568,8 +576,17 @@ void BinaryWriterSpec::WriteCommands() {
         WriteSeparator();
         WriteAction(*assert_return_command->action);
         WriteSeparator();
-        WriteKey("expected");
-        WriteConstVector(assert_return_command->expected);
+        const Expectation* expectation = assert_return_command->expected.get();
+        switch (expectation->type()) {
+          case ExpectationType::Values:
+            WriteKey("expected");
+            break;
+
+          case ExpectationType::Either:
+            WriteKey("either");
+            break;
+        }
+        WriteConstVector(expectation->expected);
         break;
       }
 
@@ -649,8 +666,8 @@ Result WriteBinarySpecScript(
     Stream* log_stream) {
   WriteBinarySpecStreamFactory module_stream_factory =
       [&](std::string_view filename) {
-        out_module_streams->emplace_back(filename,
-                                         MakeUnique<MemoryStream>(log_stream));
+        out_module_streams->emplace_back(
+            filename, std::make_unique<MemoryStream>(log_stream));
         return out_module_streams->back().stream.get();
       };
 
